@@ -24,4 +24,9 @@ class Brain:
             False: "Not Wandering"
         }
         prediction = [prediction > 0.5]
-        return result[prediction[0][0][0]]
\ No newline at end of file
+        return result[prediction[0][0][0]]
+
+    def predict_profiler(self, image):
+        tf.profiler.experimental.start(self.config.get("LOGS_FOLDER"))
+        self.model.predict(image)
+        tf.profiler.experimental.stop()
\ No newline at end of file
